"""
TexPRoject

Automatic LaTeX project management.

:copyright: (c) 2020 by Alex Rutar
:license: MIT, see LICENSE for more details.
"""

__version__ = "0.2.2"
__repo__ = "https://github.com/alexrutar/texproject"
